@@ -30,7 +30,7 @@ import hubzero.config.hubzerositeconfig
 import hubzero.data.db
 import re
 import os
-
+import json
 
 def getDefaultSite():
 	return hubzero.config.hubzerositeconfig.getHubzeroConfigOption("DEFAULT", "site")
@@ -55,7 +55,7 @@ def getWebConfigOption(optionName, hubName = ""):
 		configValues += hubconfigFileContents
 	
 	# grep for right line
-	regEx = "var\s*\$" + optionName + "\s*=\s*'(.*)';"
+	regEx = "(?:var|public)\s*\$" + optionName + "\s*=\s*'(.*)';"
 	m = re.search(regEx, configValues, re.MULTILINE | re.IGNORECASE)
 
 	# return whatever we find, if not found, this will be none type
@@ -109,11 +109,16 @@ def _writeParamField(componentOption, NewParamValueDictionary, hubName):
 	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
-	parmString = ""
-	for parm in NewParamValueDictionary:
-		parmString += parm + "=" + NewParamValueDictionary[parm] + "\n"
-		
-	sql = "UPDATE jos_components set params = %s WHERE `option` = %s"
+	if hubzero.utilities.misc.JOOMLA_25:
+		parmString = json.dumps(NewParamValueDictionary)
+		sql = "UPDATE jos_extensions set params = %s WHERE type='component' AND `element` = %s"
+	else:
+		parmString = ""
+		for parm in NewParamValueDictionary:
+			parmString += parm + "=" + NewParamValueDictionary[parm] + "\n"
+		sql = "UPDATE jos_components set params = %s WHERE `option` = %s"
+
+
 	data = (parmString, componentOption)
 	db.query_rowcount(sql, data)
 
@@ -135,17 +140,24 @@ def _buildDictionary(componentOption, hubName):
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	
 	# look up parm string and parse it on newline, for each line, parse it further based on *first* '='
-	sql = "SELECT `params` from jos_components WHERE `option`=%s"
+	if hubzero.utilities.misc.JOOMLA_25:
+		sql = "SELECT `params` from jos_extensions WHERE type='component' AND `element`=%s"
+	else:
+		sql = "SELECT `params` from jos_components WHERE `option`=%s"
+
 	data = (componentOption)
 	paramsString = db.query_selectscalar(sql, data)
-	parms = paramsString.split("\n")
 	
-	parmsDict = {}
-	for parmline in parms:
-		if parmline: # in case of any blank lines in the params field
-			n,v = parmline.split("=", 1)
-			parmsDict[n] = v
-		
+	if hubzero.utilities.misc.JOOMLA_25:
+		parmsDict = json.loads(paramsString)
+	else:
+		parmsDict = {}
+		parms = paramsString.split("\n")
+		for parmline in parms:
+			if parmline: # in case of any blank lines in the params field
+				n,v = parmline.split("=", 1)
+				parmsDict[n] = v
+
 	return parmsDict
 	
 
@@ -198,7 +210,10 @@ def setPluginEnabled(pluginFolder, pluginElement, enable, hubName = ""):
 	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 		
-	sql = "UPDATE jos_plugins set published = %s WHERE `folder` = %s AND `element` = %s"
+	if hubzero.utilities.misc.JOOMLA_25:
+		sql = "UPDATE jos_extensions set enabled = %s WHERE type='plugin' AND `folder` = %s AND `element` = %s"
+	else:
+		sql = "UPDATE jos_plugins set published = %s WHERE `folder` = %s AND `element` = %s"
 	data = (enable, pluginFolder, pluginElement)
 	db.query_rowcount(sql, data)	
 
@@ -213,7 +228,10 @@ def getPluginEnabled(pluginFolder, pluginElement, hubName = ""):
 	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 		
-	sql = "SELECT published FROM jos_plugins WHERE `folder` = %s AND `element` = %s"
+	if hubzero.utilities.misc.JOOMLA_25:
+		sql = "SELECT enabled FROM jos_extensions  WHERE type='plugins' AND `folder` = %s AND `element` = %s"
+	else:
+		sql = "SELECT published FROM jos_plugins WHERE `folder` = %s AND `element` = %s"
 	data = (pluginFolder, pluginElement)
 	published = db.query_selectscalar(sql, data)
 	return published
@@ -239,5 +257,4 @@ def getHubSiteConfig(hubname, sectionName, valueName):
                 rv = ''
 	
 	return rv
-
-
+	
